FinderReminder = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0","AceConsole-2.0","AceDB-2.0")

local addon = FinderReminder
addon.version = "2.0.$Rev: 17954 $"
addon.date = "$Date: 2006-11-24 08:13:50 -0500 (Fri, 24 Nov 2006) $"

local L = AceLibrary("AceLocale-2.2"):new("FinderReminder")
local BS = AceLibrary("Babble-Spell-2.2")

addon:RegisterDB("FinderReminderDB")
addon:RegisterDefaults("profile",{hideinbg = true})

local cmd = {
    type = "group",
    args = {
        hideinbg = {
            name = L["Hide in BG"],
            type = "toggle",
            desc = L["Hides the reminder while in a PvP battleground."],
            get = function()return addon.profile.hideinbg end,
            set = function(v) addon.profile.hideinbg = v end,
        },        
    
    }
}

addon:RegisterChatCommand({"/finderreminder","/freminder"},cmd)

local trackingSpells
do
    trackingSpells = {
        "Find Minerals","Find Herbs","Find Treasure","Track Beasts","Track Humanoids",
        "Track Undead","Track Hidden","Track Elementals","Track Demons","Track Giants",
        "Track Dragonkin","Sense Undead","Sense Demons",
    }

    for i,spell in ipairs(trackingSpells) do
        trackingSpells[BS[spell]] = true
    end
end

function addon:OnEnable()
     self:SetupHeader()
    if not self.spellButtons then
        self.spellButtons = setmetatable({},{ __index = function(t,k) t[k] = self.buttonClass:new(self.header) return t[k] end })
    end
    self:BuildFrame()
    self:BuildSpellButtons()
    self:AnchorButtons()
    
    self:RegisterEvent("PLAYER_AURAS_CHANGED",true)    
    self:RegisterEvent("PLAYER_REGEN_ENABLED","CombatUnlock")
    self:OnProfileEnable()
end

function addon:OnProfileEnable()
    self.profile = self.db.profile
end

function addon:SetupHeader()
    if self.header then return end
    local header = CreateFrame("Frame",nil,nil,"SecureStateHeaderTemplate")
    header:SetFrameStrata("DIALOG")
    self.header = header
end

function addon:BuildFrame()
    if self.frame then return end
    local f = CreateFrame("Frame",nil,UIParent)
    f:Hide()
    f:SetBackdrop(StaticPopup1:GetBackdrop())
    f:SetWidth(320)
    f:SetHeight(1)
    f:SetPoint("TOP",0,-128)
    f:EnableMouse(true)
    
    f:SetScript("OnShow",function(self)
        self:SetHeight(100)
        PlaySound("igMainMenuOpen")
    end)
    f:SetScript("OnHide",function(self)
        self:SetHeight(1)
        PlaySound("igMainMenuClose")
    end)
    
    StaticPopup1:SetPoint("TOP",f,"BOTTOM")
    f:SetAttribute("hidestates","0")
    
    local b = CreateFrame("Button",nil,f,"StaticPopupButtonTemplate")
    b:SetPoint("BOTTOM",0,15)
    b:SetWidth(128)
    b:SetHeight(20)
    b:SetText(CANCEL)
    b:SetScript("OnClick",nil)
    b:SetAttribute("newstate","0")
    b:SetAttribute("showstates","1")
    
    local t = f:CreateFontString(nil,"ARTWORK","GameFontHighlight")
    t:SetPoint("TOP",0,-16)
    t:SetText(L["Activate a tracking skill?"])
    self.header:SetAttribute("addchild",f)
    self.header:SetAttribute("addchild",b)
    b:SetFrameLevel(2)
    self.frame = f
end

function addon:BuildSpellButtons()
    if next(self.spellButtons) then return end
    for i=1,MAX_SPELLS do
        local n = GetSpellName(i,"spell")
        if not n then break end
        if trackingSpells[n] then
            self.spellButtons[#self.spellButtons + 1]:SetSpell(i)
        end
    end
    if not next(self.spellButtons) then self:UnregisterAllEvents() end
end

function addon:AnchorButtons()
    local buttons = self.spellButtons
    local prevb = buttons[1]
    local n = #buttons
    
    local w = 320
    local sw = n * 33 + 30
    w = w < sw and sw or w
    self.frame:SetWidth(w)
    prevb:SetPoint("BOTTOMLEFT",self.frame,"BOTTOMLEFT",(w - sw + 30)/2,37) 
        
    for i=2,n do
        local b = buttons[i]
        b:SetPoint("TOPLEFT",prevb,"TOPRIGHT",3,0)
        prevb = b
    end    
end

function addon:Remind(force)
    local f = self.frame
    
    if (#self.spellButtons == 0) or (not force and (f:IsVisible() or (self:IsInBG() and self.profile.hideinbg) or InCombatLockdown())) then
        return
    end
    
    self.header:SetAttribute("state","1")
end

function addon:CheckTracking()
    if(not GetTrackingTexture()) then
        if InCombatLockdown() then
            self.pendingRemind = true
        else
            self:Remind()
        end
    end
end

function addon:IsInBG()
    for i = 1, MAX_BATTLEFIELD_QUEUES do
        local status = GetBattlefieldStatus(i)
        if(status == "active") then
            return true
        end
    end
end

function addon:PLAYER_AURAS_CHANGED()
    self:RegisterEvent("PLAYER_ENTERING_WORLD","CheckTracking")
    self:RegisterEvent("PLAYER_ALIVE","CheckTracking")
    self:RegisterEvent("PLAYER_UNGHOST","CheckTracking")
    
    self:CheckTracking()
end

function addon:CombatUnlock()
    if self.pendingRemind then
        self:Remind()
        self.pendingRemind = nil
    end
end